@@ -140,6 +140,8 @@ MaemoBarcodeWindow::MaemoBarcodeWindow(QWidget *parent)
         settings->setValue("settings_version", SETTINGS_VERSION);
     }
 
+    this->AutoUseFirstPlugin = settings->value("auto_use_first_plugin", false).toBool();
+
     qDebug() << "MainWindow::MainWindow(): Initializing decoder, t=" << debugSpeedTimer.elapsed();
     decoder = new BarcodeDetector(); // create a decoder
 
@@ -272,6 +274,10 @@ void MaemoBarcodeWindow::cameraButtonPropertyModified(int num_updates, QList<Pro
     }
 }
 
+//void MaemoBarcodeWindow::RestartContinuousScanning() {
+
+//}
+
 void MaemoBarcodeWindow::changeEvent(QEvent *e) {
     if(firstChangeEvent) {
         firstChangeEvent = false;
@@ -285,7 +291,12 @@ void MaemoBarcodeWindow::changeEvent(QEvent *e) {
     if(e->type() == QEvent::ActivationChange && isActiveWindow()) {
         qDebug() << "MaemoBarcodeWindow::changeEvent(): Is active";
         if(videoWidget != NULL && isLensCoverOpen()) {
-            videoWidget->start(false);
+            if(this->continuousScanningMode==true && this->AutoUseFirstPlugin==true)
+                // we need a pause, otherwise we end up re-scanning the same barcode more than once
+                //QTimer::singleShot(2000, this, SLOT(RestartContinuousScanning()));
+                videoWidget->start(false);
+            else
+                videoWidget->start(false);
         }
     } else {
         qDebug() << "MaemoBarcodeWindow::changeEvent(): Is not active window";
@@ -367,7 +378,7 @@ void MaemoBarcodeWindow::loadPlugins() {
     //QList<bool> origPluginPresent;
 
     int numPlugins = settings->beginReadArray("plugins");
-    cout << "loadPlugins(): Loading plugin info, found " << QString("%1").arg(numPlugins).toStdString() << endl;
+    qDebug() << "loadPlugins(): Loading plugin info, found " << QString("%1").arg(numPlugins);
 
     //int max_pri=-1;
     //int pri;
@@ -398,7 +409,7 @@ void MaemoBarcodeWindow::loadPlugins() {
     this->NumEnabledPlugins=0;
 
     foreach (QString fileName, allPluginFiles) { // go through all files in the plugin dir
-        cout << "Loading " << fileName.toStdString() << endl;
+        qDebug() << "Loading " << fileName;
 
         QPluginLoader loader(fileName); // create a loader for the shared library
         QObject *plugin = loader.instance();  // load it as a QObject
@@ -407,7 +418,7 @@ void MaemoBarcodeWindow::loadPlugins() {
 
             pluginFileNames += fileName; // list all our plugin file names
             PluginInterface* interface = qobject_cast<PluginInterface*>(plugin); // cast it to our kind of interface
-            cout << "Interface name: " << interface->getName().toStdString() << endl;
+            qDebug() << "Interface name: " << interface->getName();
 
             pluginInterfaces.append(interface); // add this interface to our list of interfaces
             interface->initInterface(this); // initialize the plugin
@@ -424,7 +435,7 @@ void MaemoBarcodeWindow::loadPlugins() {
                     //pluginAction->setPriority(origPluginPriorities.value(ind));
                     pluginAction->setEnabled(origPluginEnabled.value(ind));
 
-                    cout << "loadPlugins(): Found plugin listed in settings " << pluginIdentifier.toStdString() << QString("%1").arg(pluginAction->getEnabled()).toStdString() << endl;
+                    cout << "loadPlugins(): Found plugin listed in settings " << pluginIdentifier.toStdString() << " " << QString("%1").arg(pluginAction->getEnabled()).toStdString() << endl;
 
                 }else{
                     // no we don't know about this one
@@ -433,7 +444,7 @@ void MaemoBarcodeWindow::loadPlugins() {
                     pluginAction->setEnabled(true);
 
                     //qDebug() << "loadPlugins(): Found plugin not listed in settings " << pluginIdentifier << " " << max_pri << " true";
-                    cout << "loadPlugins(): Found plugin not listed in settings " << pluginIdentifier.toStdString() << " true" << endl;
+                    cout << "loadPlugins(): Found plugin not listed in settings " << pluginIdentifier.toStdString() << " 1" << endl;
                 }
 
                 if (pluginAction->getEnabled())
@@ -478,19 +489,23 @@ void MaemoBarcodeWindow::imageAnalysed(QString barcodeType, QString barcodeData,
     ensurePluginsLoaded();
     emit barcodeAnalysedSignal(barcodeType, barcodeData); // emit a signal for whoever's listening. Especially plugins :)
 
-    // display the output (this is done before anything is added to the tblTillRoll - avoids flickering)
-    showResultsWindow(barcodeData);
+    if(this->AutoUseFirstPlugin){
+        resultsWindow->processBarcode(barcodeData);
+    }else // no point in showing it if we'll soon remove it
+        // display the output (this is done before anything is added to the tblTillRoll - avoids flickering)
+        showResultsWindow(barcodeData);
 
     getRecentDialog()->imageAnalysed(barcodeType, barcodeData, im);
 }
 
 void MaemoBarcodeWindow::showResultsWindow(QString barcodeData) {
     ensurePluginsLoaded(); // not needed as we call it earlier, put it back anyway just in case
-    this->videoWidget->stopTimedScan();
-    videoWidget->stop(false);
+    this->videoWidget->stopTimedScan(); // probably not needed either as called in fn above
+    videoWidget->stop(false); // likewise not needed as called in fn above
     resultsWindow->show();
     resultsWindow->processBarcode(barcodeData);
 }
+
 void MaemoBarcodeWindow::initLensCoverState() {
     QFile file("/sys/devices/platform/gpio-switch/cam_shutter/state");
     if (!file.open(QIODevice::ReadOnly))
@@ -686,7 +701,7 @@ void MaemoBarcodeWindow::keyPressEvent(QKeyEvent *event)
 {
     qDebug() << "Inside MaemoBarcodeWindow keypress";
 
-    if(event->key()==32){ // look for space
+    if(event->key()==Qt::Key_Space){ // look for space
         videoWidget->refocus();
 
         if(this->continuousScanningMode==true){
@@ -695,7 +710,8 @@ void MaemoBarcodeWindow::keyPressEvent(QKeyEvent *event)
             this->videoWidget->startTimedScan(this->videoWidget->timedScanInterval + 2000);
             // give it 2 more seconds of scanning time to account for the fact that focusing must also occur
         }
-    }
+    }else if(event->key()==Qt::Key_Enter)
+        this->videoWidget->refocus();
 
     event->ignore(); // let it continue to wherever it might want to go
 }
