@@ -241,7 +241,8 @@ void RecentDialog::imageAnalysed(QString barcodeType, QString barcodeData, QImag
     QVBoxLayout *lay = new QVBoxLayout();
     QLabel *imlabel = new QLabel;
     imlabel->setWordWrap(true); // this doesn't work for non-white spaced continuous lines
-    QPixmap barcodePixmap = QPixmap::fromImage(savedImg);
+    QImage barcodeImage(barcodeImageFile);
+    QPixmap barcodePixmap = QPixmap::fromImage(barcodeImage);
     imlabel->setPixmap(barcodePixmap); // This does for some reason not work as expected...
     lay->addWidget(imlabel);
     QLabel *txtlabel = new QLabel(barcodeData);
@@ -250,7 +251,7 @@ void RecentDialog::imageAnalysed(QString barcodeType, QString barcodeData, QImag
 
     delete(im);
 
-    //    ui->tblTillRoll->setIndexWidget(barcodeItem->index(),w);
+    ui->tblTillRoll->setIndexWidget(barcodeItem->index(),w);
 }
 
 
