@@ -41,6 +41,8 @@
 #include <QTimer>
 #include <QItemSelectionModel>
 #include "maemobarcodewindow.h"
+#include <QMaemo5InformationBox>
+#include "videowidget.h"
 
 #define PLUGIN_COUNT_LIMIT    6
 
@@ -59,7 +61,11 @@ ResultsWindow::ResultsWindow(MaemoBarcodeWindow *parent) :
     selectionTimer = new QTimer(this);
     connect(selectionTimer, SIGNAL(timeout()), this, SLOT(selectionTimerExpiry()));
 
-    checkPlugins(); // call it here to avoid the initial wait
+
+    //hideMeTimer = new QTimer(this);
+    //connect(hideMeTimer, SIGNAL(timeout()), this, SLOT(hideMeTimerExpiry()));
+
+    //checkPlugins(); // call it here to avoid the initial wait
 }
 
 ResultsWindow::~ResultsWindow()
@@ -95,12 +101,16 @@ void ResultsWindow::processBarcode(QString barcode) {
     }
 
     PluginUpdateCounter = 0;
+    //hideMeTimer->stop();
 
-    checkPlugins();
+    addedPlugins.clear(); // clear the plugins from the list
 
     // save the barcode text
     this->barcode_text = QString(barcode);
     checkTimer->start(1000); // check for updated plugins every x milliseconds
+
+    checkPlugins(); // move to here so that if we want to auto-run the first plugin, the timer isn't started after we disable it!
+
 }
 
 
@@ -118,20 +128,20 @@ void ResultsWindow::checkPlugins() {
     PluginUpdateCounter++;
 
     foreach(PluginAction* plugin, plugins) {
-//        qDebug() << "Checking action plugin " << plugin->getName() << "is ready" << plugin->isReady();
+        // skip plugins that are not enabled
+        if(!plugin->getEnabled())
+            continue;
+
+        qDebug() << "Checking action plugin " << plugin->getName() << "is ready" << plugin->isReady();
         if(plugin->getEnabled() && plugin->isReady() && !addedPlugins.contains(plugin)) { // check if it's ready and that it has not yet been added
             addedNewPlugins=true;
             addedPlugins.append(plugin); // add it to the list of added plugins, so we don't add it twice
-//            qDebug() << "Added plugin" << plugin->getText() << plugin->getName();
+            qDebug() << "Added plugin" << plugin->getText() << plugin->getName();
         }
     }
 
-    if(addedNewPlugins==true && this->parent->NumEnabledPlugins==1){
-        this->hide(); // hid this window
-        checkTimer->stop(); // no point in continuing to check for plugins
-        addedPlugins.at(0)->clickAction(this); // run the plugin
-        return;
-    }else if(addedNewPlugins==true){
+
+    if(addedNewPlugins==true){
         QAbstractItemModel *oldModel = ui->tblResults->model();
         PluginActionListModel *model = new PluginActionListModel(this, addedPlugins);
         ui->tblResults->setModel(model);
@@ -140,6 +150,18 @@ void ResultsWindow::checkPlugins() {
         ui->tblResults->setFixedHeight(ui->tblResults->verticalHeader()->length() + 60); // fix to make all contents of scrollwidget scroll together
     }
 
+    if(addedPlugins.length()>0  && parent->AutoUseFirstPlugin){ // && this->parent->NumEnabledPlugins==1
+        qDebug() << "AutoUseFirstPlugin, running this one";
+        checkTimer->stop(); // no point in continuing to check for plugins
+        QMaemo5InformationBox::information (this->parent, addedPlugins.at(0)->getName() + " run", 1000);
+        addedPlugins.at(0)->clickAction(this); // run the plugin
+        //hideMeTimer->singleShot(1500, this, SLOT(hideMeTimerExpiry()));
+        //this->close(); // hide this window
+        //this->parent->activateWindow(); // send it a signal so that it starts the camera again
+        //return;
+        this->parent->videoWidget->start(false);
+    }
+
     if(PluginUpdateCounter > PLUGIN_COUNT_LIMIT)
         checkTimer->stop();
 
@@ -225,3 +247,8 @@ void ResultsWindow::selectionTimerExpiry()
     QItemSelectionModel *selection = ui->tblResults->selectionModel();
     selection->clear();
 }
+
+//void ResultsWindow::hideMeTimerExpiry()
+//{
+//    this->close();
+//}
