@@ -70,7 +70,7 @@ void SettingsWindow::hideEvent(QHideEvent *) {
     // end debugging code
 
 
-    parent->NumEnabledPlugins=0;
+    //parent->NumEnabledPlugins=0;
 
     settings->beginWriteArray("plugins");
     for (int i=0; i<parent->pluginActions.size(); ++i){
@@ -85,8 +85,8 @@ void SettingsWindow::hideEvent(QHideEvent *) {
         settings->setValue("pluginPriority", action->getPriority());
         settings->setValue("pluginEnabled", action->getEnabled());
 
-        if (action->getEnabled())
-            parent->NumEnabledPlugins++;
+        //if (action->getEnabled())
+        //    parent->NumEnabledPlugins++;
     }
     settings->endArray();
 
