@@ -466,11 +466,22 @@ void VideoWidget::start(bool evenIfNotYetStarted) {
         parent->continuousScanningMode = false;
     }
 }
+
 void VideoWidget::stop(bool stopCompletely) {
     qDebug() << "VideoWidget::stop(): Called with stopCompletely = " << stopCompletely;
     if(pipeline != NULL) {
         qDebug() << "VideoWidget::stop(): Setting pipeline to paused";
         gst_element_set_state(pipeline, GST_STATE_PAUSED);
+
+//        GstEvent *event = gst_event_new_flush_start();
+//        int result = gst_element_send_event (pipeline, event);
+//        if (!result)
+//            qDebug() << "Start flush failed";
+
+//        event = gst_event_new_flush_stop();
+//        result = gst_element_send_event (pipeline, event);
+//        if (!result)
+//            qDebug() << "Start flush failed";
     }
     pipelineReady = false;
     refocusTimer->stop();
@@ -838,7 +849,7 @@ void VideoWidget::getDeviceType() {
         qDebug( "Oh no... We're something else.");
 }
 void VideoWidget::refocus() {
-    if(!focusing && pipelineReady) { // we are running and are not focusing.
+    if(!focusing && pipelineReady && this->decoder->scanning_status) { // we are running and are not focusing.
         emit focusingValueChanged(true);
         gst_element_set_state (pipeline, GST_STATE_PAUSED);
 
@@ -954,8 +965,15 @@ void VideoWidget::stopTimedScan()
 
 void VideoWidget::setContinuousScanning(bool on)
 {
-    decoder->scanning_status=on;
+    if(on==true)
+        QTimer::singleShot(100, this, SLOT(setContinuousScanningCallback())); // give the pipeline some time to clear
+    else
+        decoder->scanning_status=on;
 }
 
 
+void VideoWidget::setContinuousScanningCallback()
+{
+    decoder->scanning_status=true;
+}
 
